@@ -20,20 +20,21 @@ def get_ansi(md):
     MD.convert(md)
     ansi = MD.ansi + '\n'
     ansi = cli_utils.set_hr_widths(ansi) + "\n"
-    # The RAW html within source, incl. fenced code blocks:
-    # phs are numbered like this in the md, we replace back:
-    PH = markdown.util.HTML_PLACEHOLDER
+    ## The raw HTML within the source includes fenced code blocks.
+    ## Placeholders are numbered like this in the md, we replace back
+    ansi_placeholder_tpl = markdown.util.HTML_PLACEHOLDER
     stash = MD.htmlStash
-    for nr, ph in enumerate(stash.rawHtmlBlocks):
-        raw = unescape(ph)
-        if raw[:3].lower() == '<br':
+    for i, html_block_str in enumerate(stash.rawHtmlBlocks):
+        ansi_placeholder = ansi_placeholder_tpl % i
+        raw = unescape(html_block_str)
+        if raw.lower().startswith('<br'):
             raw = '\n'
         pre = '<pre><code'
         if raw.startswith(pre):
             _, raw = raw.split(pre, 1)
             raw = raw.split('>', 1)[1].rsplit('</code>', 1)[0]
             raw = tag_formatting.code(raw.strip(), from_fenced_block=True)
-        ansi = ansi.replace(PH % nr, raw)
+        ansi = ansi.replace(ansi_placeholder, raw)
     return ansi
 
 def main(md):
